=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2007-03-27 21:45:59 +0000
+++ bzrlib/branch.py	2007-03-28 08:49:06 +0000
@@ -2025,7 +2025,6 @@
         self._transport_server = transport_server
         self._transport_readonly_server = transport_readonly_server
         self._formats = formats
-        self._vfs_transport_factory = vfs_transport_factory
     
     def adapt(self, test):
         result = TestSuite()
@@ -2033,8 +2032,6 @@
             new_test = deepcopy(test)
             new_test.transport_server = self._transport_server
             new_test.transport_readonly_server = self._transport_readonly_server
-            if self._vfs_transport_factory:
-                new_test.vfs_transport_factory = self._vfs_transport_factory
             new_test.bzrdir_format = bzrdir_format
             new_test.branch_format = branch_format
             def make_new_test_id():

=== modified file 'bzrlib/tests/branch_implementations/__init__.py'
--- bzrlib/tests/branch_implementations/__init__.py	2007-03-28 07:48:37 +0000
+++ bzrlib/tests/branch_implementations/__init__.py	2007-03-28 08:49:06 +0000
@@ -30,7 +30,6 @@
                            )
 from bzrlib.tests import (
                           adapt_modules,
-                          default_transport,
                           TestLoader,
                           TestSuite,
                           )
@@ -64,7 +63,8 @@
     # TODO: To usefully test the SmartServer, we need to specify the bzrdir
     # format, branch format, and also the transport.
     adapter = BranchTestProviderAdapter(
-        default_transport,
+        # None here will cause the default vfs transport server to be used.
+        None,
         # None here will cause a readonly decorator to be created
         # by the TestCaseWithTransport.get_readonly_transport method.
         None,

=== modified file 'bzrlib/tests/branch_implementations/test_bound_sftp.py'
--- bzrlib/tests/branch_implementations/test_bound_sftp.py	2007-03-28 07:48:37 +0000
+++ bzrlib/tests/branch_implementations/test_bound_sftp.py	2007-03-28 08:49:06 +0000
@@ -31,10 +31,18 @@
                            )
 import bzrlib.errors as errors
 from bzrlib.tests import TestSkipped
-from bzrlib.tests.test_sftp_transport import TestCaseWithSFTPServer, paramiko_loaded
-
-
-class BoundSFTPBranch(TestCaseWithSFTPServer):
+from bzrlib.tests import TestCaseWithTransport
+from bzrlib.transport.local import LocalURLServer
+from bzrlib.transport.memory import MemoryServer
+
+
+class BoundSFTPBranch(TestCaseWithTransport):
+
+    def setUp(self):
+        TestCaseWithTransport.setUp(self)
+        self.vfs_transport_factory = MemoryServer
+        if self.transport_server is LocalURLServer:
+            self.transport_server = None
 
     def create_branches(self):
         self.build_tree(['base/', 'base/a', 'base/b'])
@@ -59,11 +67,6 @@
         self.assertEqual(['r@b-1'], wt_child.branch.revision_history())
         return b_base, wt_child
 
-    def tearDown(self):
-        self.sftp_base = None
-        bzrlib.transport.sftp.clear_connection_cache()
-        super(BoundSFTPBranch, self).tearDown()
-
     def test_simple_binding(self):
         self.build_tree(['base/', 'base/a', 'base/b', 'child/'])
         try:
@@ -332,6 +335,3 @@
     #       performance even when something fails.
 
 
-if not paramiko_loaded:
-    del BoundSFTPBranch
-

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2007-03-28 07:48:37 +0000
+++ bzrlib/tests/test_sftp_transport.py	2007-03-28 08:49:06 +0000
@@ -44,9 +44,9 @@
     if getattr(testcase, '_get_remote_is_absolute', None) is None:
         testcase._get_remote_is_absolute = True
     if testcase._get_remote_is_absolute:
-        testcase.vfs_transport_factory = SFTPAbsoluteServer
+        testcase.transport_server = SFTPAbsoluteServer
     else:
-        testcase.vfs_transport_factory = SFTPHomeDirServer
+        testcase.transport_server = SFTPHomeDirServer
     testcase.transport_readonly_server = HttpServer
 
 

=== modified file 'bzrlib/transport/chroot.py'
--- bzrlib/transport/chroot.py	2007-03-28 05:28:28 +0000
+++ bzrlib/transport/chroot.py	2007-03-28 08:49:06 +0000
@@ -22,6 +22,7 @@
 from bzrlib import errors, urlutils
 from bzrlib.transport import (
     get_transport,
+    local,
     register_transport,
     Server,
     Transport,

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2007-02-12 05:09:45 +0000
+++ bzrlib/transport/local.py	2007-03-28 08:49:06 +0000
@@ -519,7 +519,7 @@
     this just exists to tell the test code how to get to it.
     """
 
-    def setUp(self, decorated_transport=None):
+    def setUp(self):
         """Setup the server to service requests.
         
         :param decorated_transport: ignored by this implementation.

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2007-03-28 07:48:37 +0000
+++ bzrlib/transport/sftp.py	2007-03-28 08:49:06 +0000
@@ -50,6 +50,7 @@
 from bzrlib.osutils import pathjoin, fancy_rename, getcwd
 from bzrlib.trace import mutter, warning
 from bzrlib.transport import (
+    local,
     register_urlparse_netloc_protocol,
     Server,
     split_url,
@@ -1069,10 +1070,13 @@
         ssh_server.start_server(event, server)
         event.wait(5.0)
     
-    def setUp(self, vfs_server=None):
-        # XXX: TODO: make sftpserver back onto vfs_server rather than local disk.
-        assert vfs_server is None or isinstance(vfs_server, LocalURLServer), \
-            "SFTPServer currently assumes local transport, got %s" % vfs_server
+    def setUp(self, backing_server=None):
+        # XXX: TODO: make sftpserver back onto backing_server rather than local
+        # disk.
+        assert (backing_server is None or
+                isinstance(backing_server, local.LocalURLServer)), (
+            "backing_server should not be %r, because this can only serve the "
+            "local current working directory." % (backing_server,))
         self._original_vendor = ssh._ssh_vendor_manager._cached_ssh_vendor
         ssh._ssh_vendor_manager._cached_ssh_vendor = self._vendor
         if sys.platform == 'win32':
@@ -1183,11 +1187,14 @@
 
 
 class SFTPSiblingAbsoluteServer(SFTPAbsoluteServer):
-    """A test servere for sftp transports, using absolute urls to non-home."""
-
-    def setUp(self):
+    """A test server for sftp transports where only absolute paths will work.
+
+    It does this by serving from a deeply-nested directory that doesn't exist.
+    """
+
+    def setUp(self, backing_server=None):
         self._server_homedir = '/dev/noone/runs/tests/here'
-        super(SFTPSiblingAbsoluteServer, self).setUp()
+        super(SFTPSiblingAbsoluteServer, self).setUp(backing_server)
 
 
 def _sftp_connect(host, port, username, password):

